@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Stream
  */
@@ -19,7 +19,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Stream
  */
@@ -31,12 +31,12 @@ class Horde_Stream_Existing extends Horde_Stream
      * @param array $opts  Additional configuration options:
      *   - stream: (resource) [REQUIRED] The stream resource.
      *
-     * @throws Horde_Stream_Exception
+     * @throws InvalidArgumentException
      */
     public function __construct(array $opts = array())
     {
         if (!isset($opts['stream']) || !is_resource($opts['stream'])) {
-            throw new Horde_Stream_Exception('Need a stream resource.');
+            throw new InvalidArgumentException('Need a stream resource.');
         }
 
         $this->stream = $opts['stream'];
